"use server"

import prisma from "@/lib/prisma";
import { artistSchema } from "@/schemas/artists/artistSchema";
import * as z from "zod/v4";

export async function updateArtist(
  values: z.infer<typeof artistSchema>, 
  id: string
) {
  const existingSocials = await prisma.social.findMany({
    where: { artistId: id },
  });

  const updatedSocialIds = (values.socials ?? []).filter(s => s.id).map(s => s.id);

  const removedSocials = existingSocials.filter(
    (s) => !updatedSocialIds.includes(s.id)
  );

  return await prisma.artist.update({
    where: {
      id: id
    },
    data: {
      displayName: values.displayName,
      slug: values.slug,
      nickname: values.nickname,
      socials: {
        deleteMany: {
          id: { in: removedSocials.map(s => s.id) },
        },
        updateMany: (values.socials ?? [])
          .filter((s) => s.id)
          .map((s) => ({
            where: { id: s.id },
            data: {
              platform: s.platform,
              handle: s.handle,
              link: s.link,
              isPrimary: s.isPrimary,
            },
          })),
        create: (values.socials ?? [])
          .filter((s) => !s.id)
          .map((s) => ({
            platform: s.platform,
            handle: s.handle,
            link: s.link,
            isPrimary: s.isPrimary,
          })),
      },
    }
  })
}