"use server"

import prisma from "@/lib/prisma";
import { getImageBufferFromS3 } from "@/utils/getImageBufferFromS3";
import { generateExtractColorName } from "@/utils/uploadHelper";
import { extractColors } from "extract-colors";
import getPixels from "get-pixels";
import { NdArray } from "ndarray";

export async function generateExtractColors(imageId: string, fileKey: string) {
  const image = await prisma.image.findUnique({
    where: {
      id: imageId
    },
    include: {
      metadata: true
    }
  })
  if(!image) throw new Error("Image not found");
  
  const buffer = await getImageBufferFromS3(fileKey);
  const format = image.metadata?.format || "jpeg";
  const imageDataUrl = `data:${image.fileType};base64,${buffer.toString("base64")}`;

  const pixels = await new Promise<NdArray<Uint8Array>>((resolve, reject) => {
    getPixels(imageDataUrl, `image/${format}`, (err, result) => {
      if (err) reject(err);
      else resolve(result);
    });
  });

  const extracted = await extractColors({
    data: Array.from(pixels.data),
    width: pixels.shape[0],
    height: pixels.shape[1]
  });

  let typeIndex = 0;

  for (const c of extracted) {
    const name = generateExtractColorName(c.hex, c.hue, c.saturation, c.area);

    const extract = await prisma.extractColor.upsert({
      where: { name },
      create: {
        name,
        hex: c.hex,
        red: c.red,
        green: c.green,
        blue: c.blue,
        hue: c.hue,
        saturation: c.saturation,
        area: c.area,
      },
      update: {},
    });

    await prisma.imageExtractColor.upsert({
      where: {
        imageId_type: {
          imageId,
          type: `color-${typeIndex}`,
        },
      },
      create: {
        imageId,
        extractId: extract.id,
        type: `color-${typeIndex}`,
      },
      update: {},
    });

    typeIndex++;
  }

  return await prisma.imageExtractColor.findMany({
    where: { imageId },
    include: { extract: true },
  });
}