"use server"

import prisma from "@/lib/prisma";
import { VibrantSwatch } from "@/types/VibrantSwatch";
import { getImageBufferFromS3 } from "@/utils/getImageBufferFromS3";
import { generateColorName, rgbToHex } from "@/utils/uploadHelper";
import { Vibrant } from "node-vibrant/node";

export async function generateImageColors(imageId: string, fileKey: string) {
  const buffer = await getImageBufferFromS3(fileKey);
  const palette = await Vibrant.from(buffer).getPalette();

  const vibrantHexes = Object.entries(palette).map(([key, swatch]) => {
    const castSwatch = swatch as VibrantSwatch | null;
    const rgb = castSwatch?._rgb;
    const hex = castSwatch?.hex || (rgb ? rgbToHex(rgb) : undefined);
    return { type: key, hex };
  });
  
  for (const { type, hex } of vibrantHexes) {
    if (!hex) continue;

    const [r, g, b] = hex.match(/\w\w/g)!.map((h) => parseInt(h, 16));
    const name = generateColorName(hex);

    const color = await prisma.color.upsert({
      where: { name },
      create: {
        name,
        type,
        hex,
        red: r,
        green: g,
        blue: b,
      },
      update: {
        hex,
        red: r,
        green: g,
        blue: b,
      },
    });

    await prisma.imageColor.upsert({
      where: {
        imageId_type: {
          imageId,
          type,
        },
      },
      create: {
        imageId,
        colorId: color.id,
        type,
      },
      update: {
        colorId: color.id,
      },
    });
  }  

  return await prisma.imageColor.findMany({
    where: { imageId },
    include: { color: true },
  });
}