"use server"

import prisma from "@/lib/prisma";
import { imageSchema } from "@/schemas/images/imageSchema";
import * as z from "zod/v4";

export async function updateImage(
  values: z.infer<typeof imageSchema>, 
  id: string
) {
  const validated = imageSchema.safeParse(values);
  if (!validated.success) {
    throw new Error("Invalid image data");
  }

  const {
    imageName,
    originalFile,
    uploadDate,
    altText,
    description,
    fileType,
    imageData,
    creationMonth,
    creationYear,
    fileSize,
    creationDate,
    albumId,
    artistId,
    tagIds,
    categoryIds
  } = validated.data;

  const updatedImage = await prisma.image.update({
    where: { id: id },
    data: {
      imageName,
      originalFile,
      uploadDate,
      altText,
      description,
      fileType,
      imageData,
      creationMonth,
      creationYear,
      fileSize,
      creationDate,
      albumId,
      artistId,
    }
  });

  if (tagIds) {
    await prisma.image.update({
      where: { id: id },
      data: {
        tags: {
          set: tagIds.map(id => ({ id }))
        }
      }
    });
  }

  if (categoryIds) {
    await prisma.image.update({
      where: { id: id },
      data: {
        categories: {
          set: categoryIds.map(id => ({ id }))
        }
      }
    });
  }

  return updatedImage
}