import DeleteImageButton from "@/components/images/edit/DeleteImageButton";
import EditImageForm from "@/components/images/edit/EditImageForm";
import ExtractColors from "@/components/images/edit/ExtractColors";
import ImageColors from "@/components/images/edit/ImageColors";
import ImagePalettes from "@/components/images/edit/ImagePalettes";
import ImageVariants from "@/components/images/edit/ImageVariants";
import prisma from "@/lib/prisma";

export default async function ImagesEditPage({ params }: { params: { id: string } }) {
  const { id } = await params;

  const image = await prisma.image.findUnique({
    where: {
      id,
    },
    include: {
      album: true,
      artist: true,
      metadata: true,
      stats: true,
      colors: {
        include: {
          color: true
        }
      },
      extractColors: {
        include: {
          extract: true
        }
      },
      palettes: {
        include: {
          palette: {
            include: {
              items: true
            }
          }
        }
      },
      variants: true,
      categories: true,
      tags: true,
    }
  });

  const albums = await prisma.album.findMany({ orderBy: { name: "asc" }, include: { gallery: { select: { name: true } } } });
  const artists = await prisma.artist.findMany({ orderBy: { displayName: "asc" } });
  const categories = await prisma.category.findMany({ orderBy: { name: "asc" } });
  const tags = await prisma.tag.findMany({ orderBy: { name: "asc" } });

  console.log(image)

  return (
    <div>
      <h1 className="text-2xl font-bold mb-4">Edit image</h1>
      <div className="grid grid-cols-1 lg:grid-cols-2 gap-8">
        <div>
          {image ? <EditImageForm image={image} artists={artists} albums={albums} tags={tags} categories={categories} /> : 'Image not found...'}
          <div className="mt-6">
            {image && <DeleteImageButton imageId={image.id} />}
          </div>
          <div>
            {image && <ImageVariants variants={image.variants} />}
          </div>
        </div>
        <div className="space-y-6">
          <div>
            {image && <ImagePalettes palettes={image.palettes} imageId={image.id} fileKey={image.fileKey} />}
          </div>
          <div>
            {image && <ImageColors colors={image.colors} imageId={image.id} fileKey={image.fileKey} />}
          </div>
          <div>
            {image && <ExtractColors colors={image.extractColors} imageId={image.id} fileKey={image.fileKey} />}
          </div>
        </div>
      </div>
    </div>
  );
}