import { Card, CardContent, CardFooter, CardHeader, CardTitle } from "@/components/ui/card";
import { Category } from "@/generated/prisma";
import Link from "next/link";

type CategoriesWithItems = Category & {
  images: { id: string }[]
}

export default function ListCategories({ categories }: { categories: CategoriesWithItems[] }) {
  return (
    <div className="grid gap-6 sm:grid-cols-2 md:grid-cols-3 xl:grid-cols-4">
      {categories.map((cat) => (
        <Link href={`/categories/edit/${cat.id}`} key={cat.id}>
          <Card className="overflow-hidden">
            <CardHeader>
              <CardTitle className="text-base truncate">{cat.name}</CardTitle>
            </CardHeader>
            <CardContent>
              {cat.description && <p className="text-sm text-muted-foreground">{cat.description}</p>}
            </CardContent>
            <CardFooter>
              Connected to {cat.images.length} image{cat.images.length !== 1 ? "s" : ""}
            </CardFooter>
          </Card>
        </Link>
      ))}
    </div>
  );
}