"use client"

import { createCategory } from "@/actions/categories/createCategory";
import { Button } from "@/components/ui/button";
import { Form, FormControl, FormDescription, FormField, FormItem, FormLabel, FormMessage } from "@/components/ui/form";
import { Input } from "@/components/ui/input";
import { categorySchema } from "@/schemas/categories/categorySchema";
import { zodResolver } from "@hookform/resolvers/zod";
import { useRouter } from "next/navigation";
import { useForm } from "react-hook-form";
import { toast } from "sonner";
import * as z from "zod/v4";

export default function CreateCategoryForm() {
  const router = useRouter();
  const form = useForm<z.infer<typeof categorySchema>>({
    resolver: zodResolver(categorySchema),
    defaultValues: {
      name: "",
      description: ""
    },
  })

  async function onSubmit(values: z.infer<typeof categorySchema>) {
    const cat = await createCategory(values)
    if (cat) {
      toast.success("Category created")
      router.push(`/categories`)
    }
  }

  return (
    <Form {...form}>
      <form onSubmit={form.handleSubmit(onSubmit)} className="space-y-8">
        <FormField
          control={form.control}
          name="name"
          render={({ field }) => (
            <FormItem>
              <FormLabel>Category name</FormLabel>
              <FormControl>
                <Input placeholder="Category name" {...field} />
              </FormControl>
              <FormDescription>
                This is your public display name.
              </FormDescription>
              <FormMessage />
            </FormItem>
          )}
        />
        <FormField
          control={form.control}
          name="description"
          render={({ field }) => (
            <FormItem>
              <FormLabel>Category description</FormLabel>
              <FormControl>
                <Input placeholder="Category description" {...field} />
              </FormControl>
              <FormDescription>
                Description of the category.
              </FormDescription>
              <FormMessage />
            </FormItem>
          )}
        />
        <div className="flex flex-col gap-4">
          <Button type="submit">Submit</Button>
          <Button type="reset" variant="secondary" onClick={() => router.back()}>Cancel</Button>
        </div>
      </form>
    </Form>
  );
}