"use client"

import { generateImageColors } from "@/actions/images/generateImageColors";
import { Button } from "@/components/ui/button";
import { Color, ImageColor } from "@/generated/prisma";
import { useState, useTransition } from "react";
import { toast } from "sonner";

type ColorWithItems = ImageColor & {
  color: Color
};

export default function ImageColors({ colors: initialColors, imageId, fileKey }: { colors: ColorWithItems[], imageId: string, fileKey: string }) {
  const [colors, setColors] = useState(initialColors);
  const [isPending, startTransition] = useTransition();

  const handleGenerate = () => {
    startTransition(async () => {
      try {
        const newColors = await generateImageColors(imageId, fileKey);
        setColors(newColors);
        toast.success("Colors extracted successfully");
      } catch (err) {
        toast.error("Failed to extract colors");
        console.error(err);
      }
    });
  };

  return (
    <>
      <div className="flex items-center justify-between mb-2">
        <h2 className="font-semibold text-lg">Image Colors</h2>
        <Button size="sm" onClick={handleGenerate} disabled={isPending}>
          {isPending ? "Extracting..." : "Generate Palette"}
        </Button>
      </div >
      <div className="flex flex-wrap gap-2">
        {colors.map((item) => (
          <div
            key={`${item.imageId}-${item.type}`}
            className="w-10 h-10 rounded"
            style={{ backgroundColor: item.color?.hex ?? "#000000" }}
            title={`${item.type} – ${item.color?.hex}`}
          ></div>
        ))}
      </div>
    </>
  );
}