"use client";

import { generatePaletteAction } from "@/actions/images/generatePalette";
import { Button } from "@/components/ui/button";
import { ColorPalette, ColorPaletteItem, ImagePalette } from "@/generated/prisma";
import { useState, useTransition } from "react";
import { toast } from "sonner";

type PaletteWithItems = ImagePalette & {
  palette: ColorPalette & {
    items: ColorPaletteItem[]
  };
};

export default function ImagePalettes({ palettes: initialPalettes, imageId, fileKey }: { palettes: PaletteWithItems[], imageId: string, fileKey: string }) {
  const [palettes, setPalettes] = useState(initialPalettes);
  const [isPending, startTransition] = useTransition();

  const handleGenerate = () => {
    startTransition(async () => {
      try {
        const newPalettes = await generatePaletteAction(imageId, fileKey);
        setPalettes(newPalettes);
        toast.success("Palette extracted successfully");
      } catch (err) {
        toast.error("Failed to extract palette");
        console.error(err);
      }
    });
  };

  return (
    <>
      <div className="flex items-center justify-between mb-2">
        <h2 className="font-semibold text-lg">Palettes</h2>
        <Button size="sm" onClick={handleGenerate} disabled={isPending}>
          {isPending ? "Extracting..." : "Generate Palette"}
        </Button>
      </div >

      <div className="space-y-4">
        {palettes.map((imagePalette) => (
          imagePalette.type != 'error' ?
            <div key={imagePalette.id}>
              <div className="text-sm font-medium mb-1">{imagePalette.type}</div>
              <div className="flex gap-1">
                {imagePalette.palette.items
                  .filter((item) => item.tone !== null && item.hex !== null)
                  .sort((a, b) => (a.tone ?? 0) - (b.tone ?? 0))
                  .map((item) => (
                    <div
                      key={item.id}
                      className="w-6 h-6 rounded"
                      style={{ backgroundColor: item.hex ?? "#000000" }}
                      title={`Tone ${item.tone} - ${item.hex}`}
                    />
                  ))}
              </div>
            </div>
            : null
        ))}
      </div>
    </>
  );
}