"use client"

import { uploadImage } from "@/actions/images/uploadImage";
import { Button } from "@/components/ui/button";
import { Form, FormControl, FormDescription, FormField, FormItem, FormLabel, FormMessage } from "@/components/ui/form";
import { Input } from "@/components/ui/input";
import { imageUploadSchema } from "@/schemas/images/imageSchema";
import { zodResolver } from "@hookform/resolvers/zod";
import { useRouter } from "next/navigation";
import { useForm } from "react-hook-form";
import { toast } from "sonner";
import * as z from "zod/v4";


export default function UploadImageForm() {
  const router = useRouter();

  const form = useForm<z.infer<typeof imageUploadSchema>>({
    resolver: zodResolver(imageUploadSchema),
    defaultValues: {
      file: undefined,
      imageName: "",
    },
  })

  const onFileChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    const files = e.target.files;
    if (!files || files.length === 0) return;

    const file = files[0];
    const reader = new FileReader();

    reader.onloadend = () => {
      if (typeof reader.result === 'string') {
        // setPreview(reader.result as string);
      }
    };
    reader.readAsDataURL(file);
    form.setValue("file", files);
  };

  async function onSubmit(values: z.infer<typeof imageUploadSchema>) {
    const image = await uploadImage(values)
    if (image) {
      toast.success("Image created")
      router.push(`/images/edit/${image.id}`)
    }
  }

  return (
    <Form {...form}>
      <form onSubmit={form.handleSubmit(onSubmit)} className="space-y-8">
        <FormField
          control={form.control}
          name="file"
          render={() => (
            <FormItem>
              <FormLabel>Choose image to upload</FormLabel>
              <FormControl>
                <Input
                  type="file"
                  accept="image/*"
                  onChange={(e) => onFileChange(e)}
                />
              </FormControl>
            </FormItem>
          )}
        />
        <FormField
          control={form.control}
          name="imageName"
          render={({ field }) => (
            <FormItem>
              <FormLabel>Image name</FormLabel>
              <FormControl>
                <Input placeholder="Image name" {...field} />
              </FormControl>
              <FormDescription>

              </FormDescription>
              <FormMessage />
            </FormItem>
          )}
        />
        <div className="flex flex-col gap-4">
          <Button type="submit">Submit</Button>
          <Button type="reset" variant="secondary" onClick={() => router.back()}>Cancel</Button>
        </div>
      </form>
    </Form>
  );
}