import { Card, CardContent, CardFooter, CardHeader, CardTitle } from "@/components/ui/card";
import { ColorPalette, ColorPaletteItem } from "@/generated/prisma";
import Link from "next/link";

type PalettesWithItems = ColorPalette & {
  items: ColorPaletteItem[],
  images: { id: string }[]
}

export default function ListPalettes({ palettes }: { palettes: PalettesWithItems[] }) {
  return (
    <div className="grid gap-6 sm:grid-cols-2 md:grid-cols-3 xl:grid-cols-4">
      {palettes.map((palette) => (
        <Link href={`/palettes/${palette.id}`} key={palette.id}>
          <Card className="overflow-hidden">
            <CardHeader>
              <CardTitle className="text-base truncate">{palette.name}</CardTitle>
            </CardHeader>
            <CardContent>
              <div className="flex flex-wrap gap-2">
                {palette.items.map((item) => (
                  <div
                    key={item.id}
                    className="w-10 h-10 rounded-full border"
                    style={{ backgroundColor: item.hex ?? "#ccc" }}
                    title={item.hex ?? "n/a"}
                  />
                ))}
              </div>
            </CardContent>
            <CardFooter>
              Used by {palette.images.length} image{palette.images.length !== 1 ? "s" : ""}
            </CardFooter>
          </Card>
        </Link>
      ))}
    </div>
  );
}