"use client"

import { deleteTag } from "@/actions/tags/deleteTag";
import { updateTag } from "@/actions/tags/updateTag";
import { Button } from "@/components/ui/button";
import { Form, FormControl, FormDescription, FormField, FormItem, FormLabel, FormMessage } from "@/components/ui/form";
import { Input } from "@/components/ui/input";
import { Tag } from "@/generated/prisma";
import { tagSchema } from "@/schemas/tags/tagSchema";
import { zodResolver } from "@hookform/resolvers/zod";
import { useRouter } from "next/navigation";
import { useForm } from "react-hook-form";
import { toast } from "sonner";
import * as z from "zod/v4";

export default function EditTagForm({ tag }: { tag: Tag }) {
  const router = useRouter();
  const form = useForm<z.infer<typeof tagSchema>>({
    resolver: zodResolver(tagSchema),
    defaultValues: {
      name: tag.name,
      description: tag.description || "",
    },
  })

  async function onSubmit(values: z.infer<typeof tagSchema>) {
    const updatedTag = await updateTag(values, tag.id)
    if (updatedTag) {
      toast.success("Tag updated")
      router.push(`/tags`)
    }
  }

  return (
    <div className="flex flex-col gap-8">
      <Form {...form}>
        <form onSubmit={form.handleSubmit(onSubmit)} className="space-y-8">
          <FormField
            control={form.control}
            name="name"
            render={({ field }) => (
              <FormItem>
                <FormLabel>Tag name</FormLabel>
                <FormControl>
                  <Input placeholder="Tag name" {...field} />
                </FormControl>
                <FormDescription>
                  This is your public display name.
                </FormDescription>
                <FormMessage />
              </FormItem>
            )}
          />
          <FormField
            control={form.control}
            name="description"
            render={({ field }) => (
              <FormItem>
                <FormLabel>Tag description (optional)</FormLabel>
                <FormControl>
                  <Input placeholder="Tag description" {...field} />
                </FormControl>
                <FormDescription>
                  Description of the Category.
                </FormDescription>
                <FormMessage />
              </FormItem>
            )}
          />
          <div className="flex flex-col gap-4">
            <Button type="submit">Submit</Button>
            <Button type="reset" variant="secondary" onClick={() => router.back()}>Cancel</Button>
          </div>
        </form>
      </Form>
      <div>
        <Button
          type="button"
          variant="destructive"
          onClick={async () => {
            await deleteTag(tag.id);
            toast.success("Tag deleted");
            router.push("/tags");
          }}
        >
          Delete Tag
        </Button>
      </div>
    </div>
  );
}