import * as z from "zod/v4";

export const imageUploadSchema = z.object({
  imageName: z.string().min(1, "Image name is required"),
  file: z
    .custom<FileList>()
    .refine((files) => files instanceof FileList && files.length > 0, {
      message: "Image file is required",
    }),
})

export const imageSchema = z.object({
  fileKey: z.string().min(1, "File key is required"),
  imageName: z.string().min(1, "Image name is required"),
  originalFile: z.string().min(1, "Original file is required"),
  uploadDate: z.date(),
  
  altText: z.string().optional(),
  description: z.string().optional(),
  fileType: z.string().optional(),
  source: z.string().optional(),

  creationMonth: z.number().min(1).max(12).optional(),
  creationYear: z.number().min(1900).max(2100).optional(),
  fileSize: z.number().optional(),
  creationDate: z.date().optional(),

  albumId: z.string().optional(),
  artistId: z.string().optional(),
  categoryIds: z.array(z.string()).optional(),
  tagIds: z.array(z.string()).optional(),
})