import sharp from "sharp";

export async function determineBestWatermarkPosition(imageBuffer: Buffer): Promise<sharp.Gravity> {
  const positions = [
    { name: "center", left: 0.25, top: 0.25 },
    { name: "northwest", left: 0, top: 0 },
    { name: "northeast", left: 0.5, top: 0 },
    { name: "southwest", left: 0, top: 0.5 },
    { name: "southeast", left: 0.5, top: 0.5 },
  ] as const;

  const lowResSize = 64;
  const image = sharp(imageBuffer).removeAlpha().greyscale();
  // const { width = lowResSize, height = lowResSize } = await image.metadata();

  const resized = await image
    .resize(lowResSize, lowResSize, { fit: "inside" })
    .raw()
    .toBuffer();

  const getBrightness = (x0: number, y0: number, boxW: number, boxH: number) => {
    let sum = 0;
    let count = 0;
    for (let y = y0; y < y0 + boxH; y++) {
      for (let x = x0; x < x0 + boxW; x++) {
        const idx = y * lowResSize + x;
        sum += resized[idx];
        count++;
      }
    }
    return sum / count;
  };

  const boxW = Math.floor(lowResSize * 0.5);
  const boxH = Math.floor(lowResSize * 0.5);

  let bestPos: sharp.Gravity = "center";
  let bestBrightness = -1;

  for (const pos of positions) {
    const x0 = Math.floor(pos.left * lowResSize);
    const y0 = Math.floor(pos.top * lowResSize);
    const brightness = getBrightness(x0, y0, boxW, boxH);
    if (brightness > bestBrightness) {
      bestBrightness = brightness;
      bestPos = pos.name;
    }
  }

  return bestPos;
}